---
name: Bug report
about: If Arbor crashes, produces incorrect output or does something unexpected, please create a report to help us improve.
title: ''
labels:
- 'bug'
assignees: ''

---
<!-- Please add relevant labels to categorize your bug. For instance, version of Arbor, output of `arbor.config()`, some details of the environment. -->

**Describe the bug**
<!-- A clear and concise description of what the bug is, steps to reproduce, expected behavior, etc. -->

**Context**
<!-- Add any other context about the problem here (e.g. OS, Arbor version, etc.). -->
